@@ -6,11 +6,11 @@ use std::time::Duration;
 
 use eyre::eyre;
 
-use branchless::testing::{make_git, Git, GitRunOptions};
+use lib::testing::{make_git, Git, GitRunOptions};
 use portable_pty::{native_pty_system, CommandBuilder, PtySize};
 
-const CARRIAGE_RETURN: &'static str = "\r";
-const END_OF_TEXT: &'static str = "\x03";
+const CARRIAGE_RETURN: &str = "\r";
+const END_OF_TEXT: &str = "\x03";
 
 #[test]
 fn test_prev() -> eyre::Result<()> {
@@ -23,6 +23,7 @@ fn test_prev() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["prev"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout f777ecc9b0db5ed372b2615695191a8a17f79f24
+        branchless: running command: <git-executable> branchless smartlog
         @ f777ecc create initial.txt
         |
         O 62fc20d (master) create test1.txt
@@ -66,6 +67,7 @@ fn test_prev_multiple() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["prev", "2"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout f777ecc9b0db5ed372b2615695191a8a17f79f24
+        branchless: running command: <git-executable> branchless smartlog
         @ f777ecc create initial.txt
         :
         O 96d1c37 (master) create test2.txt
@@ -89,6 +91,7 @@ fn test_next_multiple() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["next", "2"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 96d1c37a3d4363611c49f7e52186e189a04c531f
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         o 62fc20d create test1.txt
@@ -136,6 +139,7 @@ fn test_next_ambiguous() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["next", "--oldest"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 62fc20d2a290daea0d52bdc2ed2ad4be6491010e
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |\
         | @ 62fc20d create test1.txt
@@ -151,6 +155,7 @@ fn test_next_ambiguous() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["next", "--newest"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 98b9119d16974f372e76cb64a3b77c528fc0b18b
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |\
         | o 62fc20d create test1.txt
@@ -223,6 +228,7 @@ fn test_next_on_master() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["next", "2"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 70deb1e28791d8e7dd5a1f0c871a51b91282562f
+        branchless: running command: <git-executable> branchless smartlog
         :
         O 96d1c37 (master) create test2.txt
         |
@@ -248,6 +254,7 @@ fn test_next_on_master2() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["next"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 70deb1e28791d8e7dd5a1f0c871a51b91282562f
+        branchless: running command: <git-executable> branchless smartlog
         :
         O 62fc20d (master) create test1.txt
         |
@@ -276,6 +283,7 @@ fn test_next_no_more_children() -> eyre::Result<()> {
         insta::assert_snapshot!(stdout, @r###"
         No more child commits to go to after traversing 2 children.
         branchless: running command: <git-executable> checkout 70deb1e28791d8e7dd5a1f0c871a51b91282562f
+        branchless: running command: <git-executable> branchless smartlog
         :
         O 96d1c37 (master) create test2.txt
         |
@@ -519,6 +527,7 @@ fn test_navigation_traverse_all_the_way() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["prev", "-a"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 62fc20d2a290daea0d52bdc2ed2ad4be6491010e
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         @ 62fc20d create test1.txt
@@ -533,6 +542,7 @@ fn test_navigation_traverse_all_the_way() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["next", "-a"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 70deb1e28791d8e7dd5a1f0c871a51b91282562f
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         o 62fc20d create test1.txt
@@ -564,6 +574,7 @@ fn test_navigation_traverse_branches() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["prev", "-b", "2"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout foo
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         o 62fc20d create test1.txt
@@ -580,6 +591,7 @@ fn test_navigation_traverse_branches() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["prev", "-a", "-b"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout foo
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         o 62fc20d create test1.txt
@@ -596,6 +608,7 @@ fn test_navigation_traverse_branches() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["prev", "-b"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout master
+        branchless: running command: <git-executable> branchless smartlog
         @ f777ecc (> master) create initial.txt
         |
         o 62fc20d create test1.txt
@@ -614,6 +627,7 @@ fn test_navigation_traverse_branches() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["next", "-b", "2"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout bar
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         o 62fc20d create test1.txt
@@ -632,6 +646,7 @@ fn test_navigation_traverse_branches() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["next", "-a", "-b"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout bar
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         o 62fc20d create test1.txt
@@ -664,6 +679,7 @@ fn test_traverse_branches_ambiguous() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["prev", "--all", "--branch"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 62fc20d2a290daea0d52bdc2ed2ad4be6491010e
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         @ 62fc20d (bar, foo) create test1.txt
@@ -808,6 +824,7 @@ fn test_navigation_merge() -> eyre::Result<()> {
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 25497cb08387d7d20aa741398b73ce7f924afdb5 --merge
         M	conflicting.txt
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         @ 25497cb create conflicting.txt
@@ -870,6 +887,7 @@ fn test_navigation_force() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["prev", "--force"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout 25497cb08387d7d20aa741398b73ce7f924afdb5 --force
+        branchless: running command: <git-executable> branchless smartlog
         O f777ecc (master) create initial.txt
         |
         @ 25497cb create conflicting.txt
@@ -900,6 +918,7 @@ fn test_navigation_checkout_flags() -> eyre::Result<()> {
             let (stdout, _stderr) = git.run(&["branchless", "checkout", "-b", "foo", "HEAD^"])?;
             insta::assert_snapshot!(stdout, @r###"
             branchless: running command: <git-executable> checkout HEAD^ -b foo
+            branchless: running command: <git-executable> branchless smartlog
             :
             @ 62fc20d (> foo) create test1.txt
             |
@@ -911,6 +930,7 @@ fn test_navigation_checkout_flags() -> eyre::Result<()> {
             let (stdout, _stderr) = git.run(&["branchless", "checkout", "-b", "bar"])?;
             insta::assert_snapshot!(stdout, @r###"
             branchless: running command: <git-executable> checkout -b bar
+            branchless: running command: <git-executable> branchless smartlog
             :
             @ 62fc20d (> bar, foo) create test1.txt
             |
@@ -927,6 +947,7 @@ fn test_navigation_checkout_flags() -> eyre::Result<()> {
             let (stdout, _stderr) = git.run(&["branchless", "checkout", "-f", "HEAD~2"])?;
             insta::assert_snapshot!(stdout, @r###"
             branchless: running command: <git-executable> checkout HEAD~2 -f
+            branchless: running command: <git-executable> branchless smartlog
             :
             @ 62fc20d create test1.txt
             :
@@ -942,6 +963,7 @@ fn test_navigation_checkout_flags() -> eyre::Result<()> {
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout HEAD~2 -m
         M	test1.txt
+        branchless: running command: <git-executable> branchless smartlog
         :
         @ 62fc20d create test1.txt
         :
@@ -961,6 +983,7 @@ fn test_navigation_checkout_target_only() -> eyre::Result<()> {
         let (stdout, _stderr) = git.run(&["branchless", "checkout", "master"])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout master
+        branchless: running command: <git-executable> branchless smartlog
         @ f777ecc (> master) create initial.txt
         "###);
     }
